[rkward-cvs] SF.net SVN: rkward:[4375] trunk/rkward/rkward

tfry at users.sourceforge.net tfry at users.sourceforge.net
Tue Oct 16 07:54:50 UTC 2012


Revision: 4375
          http://rkward.svn.sourceforge.net/rkward/?rev=4375&view=rev
Author:   tfry
Date:     2012-10-16 07:54:50 +0000 (Tue, 16 Oct 2012)
Log Message:
-----------
RKMatrixInput will use the text matrix, so fix API, there.

Modified Paths:
--------------
    trunk/rkward/rkward/dataeditor/rktextmatrix.cpp
    trunk/rkward/rkward/dataeditor/rktextmatrix.h
    trunk/rkward/rkward/rbackend/rpackages/rkward/R/ver.R

Modified: trunk/rkward/rkward/dataeditor/rktextmatrix.cpp
===================================================================
--- trunk/rkward/rkward/dataeditor/rktextmatrix.cpp	2012-10-16 07:37:46 UTC (rev 4374)
+++ trunk/rkward/rkward/dataeditor/rktextmatrix.cpp	2012-10-16 07:54:50 UTC (rev 4375)
@@ -2,7 +2,7 @@
                           rktextmatrix  -  description
                              -------------------
     begin                : Thu Nov 08 2007
-    copyright            : (C) 2007, 2010 by Thomas Friedrichsmeier
+    copyright            : (C) 2007, 2010, 2012 by Thomas Friedrichsmeier
     email                : tfry at users.sourceforge.net
  ***************************************************************************/
 
@@ -162,16 +162,19 @@
 	return (rows[row][col]);
 }
 
-QString* RKTextMatrix::getColumn (int col) const {
+QStringList RKTextMatrix::getColumn (int col) const {
 	RK_TRACE (EDITOR);
 
 	if (col > colcount) {
-		return 0;
+		return QStringList ();
 	}
 
-	QString* ret = new QString[rows.size ()];
+	QStringList ret;
+#if QT_VERSION >= 0x040700
+	ret.reserve (rows.size ());
+#endif
 	for (int i = 0; i < rows.size (); ++i) {
-		ret[i] = rows[i][col];
+		ret.append (rows[i][col]);
 	}
 	return ret;
 }

Modified: trunk/rkward/rkward/dataeditor/rktextmatrix.h
===================================================================
--- trunk/rkward/rkward/rbackend/rpackages/rkward/R/ver.R	2012-10-16 07:37:46 UTC (rev 4374)
+++ trunk/rkward/rkward/rbackend/rpackages/rkward/R/ver.R	2012-10-16 07:54:50 UTC (rev 4375)
@@ -3,4 +3,4 @@
 # rkward/SetVersionNumber.cmake
 
 #' @export
-".rk.app.version" <- "0.5.7z+0.6.0+pre1"
+".rk.app.version" <- "0.6.0z+0.6.1+devel1"

This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.





More information about the rkward-tracker mailing list
--- trunk/rkward/rkward/dataeditor/rktextmatrix.h	2012-10-16 07:37:46 UTC (rev 4374)
+++ trunk/rkward/rkward/dataeditor/rktextmatrix.h	2012-10-16 07:54:50 UTC (rev 4375)
@@ -2,7 +2,7 @@
                           rktextmatrix  -  description
                              -------------------
     begin                : Thu Nov 08 2007
-    copyright            : (C) 2007, 2010 by Thomas Friedrichsmeier
+    copyright            : (C) 2007, 2010, 2012 by Thomas Friedrichsmeier
     email                : tfry at users.sourceforge.net
  ***************************************************************************/
 
@@ -45,8 +45,8 @@
 	void appendRow (const QStringList& row);
 
 	QString getText (int row, int col) const;
-	/** get the contents of an entire column at once. It's your responsibility to delete the data when done. The returned array has length numRows() */
-	QString* getColumn (int col) const;
+	/** get the contents of an entire column at once. It's your responsibility to delete the data when done. The returned list has length numRows() */
+	QStringList getColumn (int col) const;
 	/** get the contents of an entire row at once */
 	QStringList getRow (int row) const;
 

Modified: trunk/rkward/rkward/rbackend/rpackages/rkward/R/ver.R
===================================================================